"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    application_name: str,
    version_label: str,
    description: str = None,
    source_build_information: Dict = None,
    source_bundle: Dict = None,
    build_configuration: Dict = None,
    auto_create_application: bool = None,
    process: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an application version for the specified application. You can create an application version from a source bundle in Amazon S3, a commit in AWS CodeCommit, or the output of an AWS CodeBuild build as follows: Specify a commit in an AWS CodeCommit repository with SourceBuildInformation. Specify a build in an AWS CodeBuild with SourceBuildInformation and BuildConfiguration. Specify a source bundle in S3 with SourceBundle  Omit both SourceBuildInformation and SourceBundle to use the default sample application.  After you create an application version with a specified Amazon S3 bucket and key location, you can't change that Amazon S3 location. If you change the Amazon S3 location, you receive an exception when you attempt to launch an environment from the application version.

    Args:
        application_name(str):  The name of the application. If no application is found with this name, and AutoCreateApplication is false, returns an InvalidParameterValue error. .
        version_label(str): A label identifying this version. Constraint: Must be unique per application. If an application version already exists with this label for the specified application, AWS Elastic Beanstalk returns an InvalidParameterValue error. .
        description(str, optional): A description of this application version. Defaults to None.
        source_build_information(Dict, optional): Specify a commit in an AWS CodeCommit Git repository to use as the source code for the application version. Defaults to None.
        source_bundle(Dict, optional): The Amazon S3 bucket and key that identify the location of the source bundle for this version.  The Amazon S3 bucket must be in the same region as the environment.  Specify a source bundle in S3 or a commit in an AWS CodeCommit repository (with SourceBuildInformation), but not both. If neither SourceBundle nor SourceBuildInformation are provided, Elastic Beanstalk uses a sample application. Defaults to None.
        build_configuration(Dict, optional): Settings for an AWS CodeBuild build. Defaults to None.
        auto_create_application(bool, optional): Set to true to create an application with the specified name if it doesn't already exist. Defaults to None.
        process(bool, optional): Pre-processes and validates the environment manifest (env.yaml) and configuration files (*.config files in the .ebextensions folder) in the source bundle. Validating configuration files can identify issues prior to deploying the application version to an environment. You must turn processing on for application versions that you create using AWS CodeBuild or AWS CodeCommit. For application versions built from a source bundle in Amazon S3, processing is optional.  The Process option validates Elastic Beanstalk configuration files. It doesn't validate your application's configuration files, like proxy server or Docker configuration. . Defaults to None.
        tags(List, optional): Specifies the tags applied to the application version. Elastic Beanstalk applies these tags only to the application version. Environments that use the application version don't inherit the tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.version.create(
                ctx, application_name=value, version_label=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.version.create application_name=value, version_label=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="create_application_version",
        op_kwargs={
            "ApplicationName": application_name,
            "VersionLabel": version_label,
            "Description": description,
            "SourceBuildInformation": source_build_information,
            "SourceBundle": source_bundle,
            "BuildConfiguration": build_configuration,
            "AutoCreateApplication": auto_create_application,
            "Process": process,
            "Tags": tags,
        },
    )


async def delete(
    hub,
    ctx,
    application_name: str,
    version_label: str,
    delete_source_bundle: bool = None,
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified version from the specified application.  You cannot delete an application version that is associated with a running environment.

    Args:
        application_name(str): The name of the application to which the version belongs.
        version_label(str): The label of the version to delete.
        delete_source_bundle(bool, optional): Set to true to delete the source bundle from your storage bucket. Otherwise, the application version is deleted only from Elastic Beanstalk and the source bundle remains in Amazon S3. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.version.delete(
                ctx, application_name=value, version_label=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.version.delete application_name=value, version_label=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="delete_application_version",
        op_kwargs={
            "ApplicationName": application_name,
            "VersionLabel": version_label,
            "DeleteSourceBundle": delete_source_bundle,
        },
    )


async def describe_all(
    hub,
    ctx,
    application_name: str = None,
    version_labels: List = None,
    max_records: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieve a list of application versions.

    Args:
        application_name(str, optional): Specify an application name to show only application versions for that application. Defaults to None.
        version_labels(List, optional): Specify a version label to show a specific application version. Defaults to None.
        max_records(int, optional): For a paginated request. Specify a maximum number of application versions to include in each response. If no MaxRecords is specified, all available application versions are retrieved in a single response. Defaults to None.
        next_token(str, optional): For a paginated request. Specify a token from a previous response page to retrieve the next response page. All other parameter values must be identical to the ones specified in the initial request. If no NextToken is specified, the first page is retrieved. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.version.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.version.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="describe_application_versions",
        op_kwargs={
            "ApplicationName": application_name,
            "VersionLabels": version_labels,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, application_name: str, version_label: str, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified application version to have the specified properties.  If a property (for example, description) is not provided, the value remains unchanged. To clear properties, specify an empty string.

    Args:
        application_name(str): The name of the application associated with this version.  If no application is found with this name, UpdateApplication returns an InvalidParameterValue error.
        version_label(str): The name of the version to update. If no application version is found with this label, UpdateApplication returns an InvalidParameterValue error. .
        description(str, optional): A new description for this version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.application.version.update(
                ctx, application_name=value, version_label=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.application.version.update application_name=value, version_label=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="update_application_version",
        op_kwargs={
            "ApplicationName": application_name,
            "VersionLabel": version_label,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def discover(
    hub, ctx, container_instance: str = None, cluster: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     This action is only used by the Amazon ECS agent, and it is not intended for use outside of the agent.  Returns an endpoint for the Amazon ECS agent to poll for updates.

    Args:
        container_instance(str, optional): The container instance ID or full ARN of the container instance. The ARN contains the arn:aws:ecs namespace, followed by the Region of the container instance, the account ID of the container instance owner, the container-instance namespace, and then the container instance ID. For example, arn:aws:ecs:region:aws_account_id:container-instance/container_instance_ID. Defaults to None.
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster to which the container instance belongs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.poll_endpoint.discover(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.poll_endpoint.discover
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="discover_poll_endpoint",
        op_kwargs={"containerInstance": container_instance, "cluster": cluster},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of delegations from an audit owner to a delegate.

    Args:
        next_token(str, optional):  The pagination token used to fetch the next set of results. . Defaults to None.
        max_results(int, optional):  Represents the maximum number of results per page, or per API request call. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.delegation.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.delegation.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_delegations",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def disassociate(hub, ctx, graph_arn: str) -> None:
    r"""
    **Autogenerated function**

    Removes the member account from the specified behavior graph. This operation can only be called by a member account that has the ENABLED status.

    Args:
        graph_arn(str): The ARN of the behavior graph to remove the member account from. The member account's member status in the behavior graph must be ENABLED.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.detective.membership.disassociate(ctx, graph_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.detective.membership.disassociate graph_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="detective",
        operation="disassociate_membership",
        op_kwargs={"GraphArn": graph_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def create(hub, ctx, resource_arn: str, tags: Dict = None) -> None:
    r"""
    **Autogenerated function**

    Add a tag to a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource tag.
        tags(Dict, optional): The key-value pair for the resource tag. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.tags.create(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.tags.create resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="create_tags",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def delete(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes a tag from a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource tag.
        tag_keys(List): An array of tag keys to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.tags.delete(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.tags.delete resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="delete_tags",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )


async def list_(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists tags for a resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource tag.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mq.tags.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mq.tags.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mq",
        operation="list_tags",
        op_kwargs={"ResourceArn": resource_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    cluster_arn: str,
    current_version: str,
    target_kafka_version: str,
    configuration_info: Dict = None,
) -> Dict:
    r"""
        **Autogenerated function**


        Updates the Apache Kafka version for the cluster.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) of the cluster to be updated.
    .
            configuration_info(Dict, optional):
    The custom configuration that should be applied on the new version of cluster.
    . Defaults to None.
            current_version(str):
    Current cluster version.
    .
            target_kafka_version(str):
    Target Kafka version.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.cluster.kafka_version.update(
                    ctx, cluster_arn=value, current_version=value, target_kafka_version=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.cluster.kafka_version.update cluster_arn=value, current_version=value, target_kafka_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="update_cluster_kafka_version",
        op_kwargs={
            "ClusterArn": cluster_arn,
            "ConfigurationInfo": configuration_info,
            "CurrentVersion": current_version,
            "TargetKafkaVersion": target_kafka_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, authentication_token: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details of the current user for whom the authentication token was generated. This is not a valid action for SigV4 (administrative API) clients. This action requires an authentication token. To get an authentication token, register an application with Amazon WorkDocs. For more information, see Authentication and Access Control for User Applications in the Amazon WorkDocs Developer Guide.

    Args:
        authentication_token(str): Amazon WorkDocs authentication token.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.current_user.get(ctx, authentication_token=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.current_user.get authentication_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="get_current_user",
        op_kwargs={"AuthenticationToken": authentication_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    template_name: str,
    template_type: str,
    next_token: str = None,
    page_size: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about all the versions of a specific message template.

    Args:
        next_token(str, optional): The  string that specifies which page of results to return in a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        template_name(str): The name of the message template. A template name must start with an alphanumeric character and can contain a maximum of 128 characters. The characters can be alphanumeric characters, underscores (_), or hyphens (-). Template names are case sensitive.
        template_type(str): The type of channel that the message template is designed for. Valid values are: EMAIL, PUSH, SMS, and VOICE.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.template.version.list_all(
                ctx, template_name=value, template_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.template.version.list_all template_name=value, template_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="list_template_versions",
        op_kwargs={
            "NextToken": next_token,
            "PageSize": page_size,
            "TemplateName": template_name,
            "TemplateType": template_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    deployment_type: str,
    group_id: str,
    amzn_client_token: str = None,
    deployment_id: str = None,
    group_version_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a deployment. ''CreateDeployment'' requests are idempotent with respect to the ''X-Amzn-Client-Token'' token and the request parameters.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        deployment_id(str, optional): The ID of the deployment if you wish to redeploy a previous deployment. Defaults to None.
        deployment_type(str): The type of deployment. When used for ''CreateDeployment'', only ''NewDeployment'' and ''Redeployment'' are valid.
        group_id(str): The ID of the Greengrass group.
        group_version_id(str, optional): The ID of the group version to be deployed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.deployment.init.create(
                ctx, deployment_type=value, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.deployment.init.create deployment_type=value, group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="create_deployment",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "DeploymentId": deployment_id,
            "DeploymentType": deployment_type,
            "GroupId": group_id,
            "GroupVersionId": group_version_id,
        },
    )


async def list_all(
    hub, ctx, group_id: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a history of deployments for the group.

    Args:
        group_id(str): The ID of the Greengrass group.
        max_results(str, optional): The maximum number of results to be returned per request. Defaults to None.
        next_token(str, optional): The token for the next set of results, or ''null'' if there are no additional results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.deployment.init.list_all(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.deployment.init.list_all group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="list_deployments",
        op_kwargs={
            "GroupId": group_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def reset(
    hub, ctx, group_id: str, amzn_client_token: str = None, force: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Resets a group's deployments.

    Args:
        amzn_client_token(str, optional): A client token used to correlate requests and responses. Defaults to None.
        force(bool, optional): If true, performs a best-effort only core reset. Defaults to None.
        group_id(str): The ID of the Greengrass group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.deployment.init.reset(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.deployment.init.reset group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="reset_deployments",
        op_kwargs={
            "AmznClientToken": amzn_client_token,
            "Force": force,
            "GroupId": group_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, attribute_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of attributes attached to an account

    Args:
        attribute_names(List, optional): A list of attribute names. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.account_attribute.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.account_attribute.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_account_attributes",
        op_kwargs={"AttributeNames": attribute_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(
    hub, ctx, stream_arn: str, limit: int = None, exclusive_start_shard_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a stream, including the current status of the stream, its Amazon Resource Name (ARN), the composition of its shards, and its corresponding DynamoDB table.  You can call DescribeStream at a maximum rate of 10 times per second.  Each shard in the stream has a SequenceNumberRange associated with it. If the SequenceNumberRange has a StartingSequenceNumber but no EndingSequenceNumber, then the shard is still open (able to receive more stream records). If both StartingSequenceNumber and EndingSequenceNumber are present, then that shard is closed and can no longer receive more data.

    Args:
        stream_arn(str): The Amazon Resource Name (ARN) for the stream.
        limit(int, optional): The maximum number of shard objects to return. The upper limit is 100. Defaults to None.
        exclusive_start_shard_id(str, optional): The shard ID of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedShardId in the previous operation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodbstream.stream.describe(ctx, stream_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodbstream.stream.describe stream_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodbstreams",
        operation="describe_stream",
        op_kwargs={
            "StreamArn": stream_arn,
            "Limit": limit,
            "ExclusiveStartShardId": exclusive_start_shard_id,
        },
    )


async def list_all(
    hub,
    ctx,
    table_name: str = None,
    limit: int = None,
    exclusive_start_stream_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of stream ARNs associated with the current account and endpoint. If the TableName parameter is present, then ListStreams will return only the streams ARNs for that table.  You can call ListStreams at a maximum rate of 5 times per second.

    Args:
        table_name(str, optional): If this parameter is provided, then only the streams associated with this table name are returned. Defaults to None.
        limit(int, optional): The maximum number of streams to return. The upper limit is 100. Defaults to None.
        exclusive_start_stream_arn(str, optional): The ARN (Amazon Resource Name) of the first item that this operation will evaluate. Use the value that was returned for LastEvaluatedStreamArn in the previous operation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodbstream.stream.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodbstream.stream.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodbstreams",
        operation="list_streams",
        op_kwargs={
            "TableName": table_name,
            "Limit": limit,
            "ExclusiveStartStreamArn": exclusive_start_stream_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(
    hub, ctx, automation_execution_id: str, signal_type: str, payload: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Sends a signal to an Automation execution to change the current behavior or status of the execution.

    Args:
        automation_execution_id(str): The unique identifier for an existing Automation execution that you want to send the signal to.
        signal_type(str): The type of signal to send to an Automation execution. .
        payload(Dict, optional): The data sent with the signal. The data schema depends on the type of signal used in the request. For Approve and Reject signal types, the payload is an optional comment that you can send with the signal type. For example:  Comment="Looks good"  For StartStep and Resume signal types, you must send the name of the Automation step to start or resume as the payload. For example:  StepName="step1"  For the StopStep signal type, you must send the step execution ID as the payload. For example:  StepExecutionId="97fff367-fc5a-4299-aed8-0123456789ab" . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.automation.signal.send(
                ctx, automation_execution_id=value, signal_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.automation.signal.send automation_execution_id=value, signal_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="send_automation_signal",
        op_kwargs={
            "AutomationExecutionId": automation_execution_id,
            "SignalType": signal_type,
            "Payload": payload,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, project_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists resources associated with a project in AWS CodeStar.

    Args:
        project_id(str): The ID of the project.
        next_token(str, optional): The continuation token for the next set of results, if the results cannot be returned in one response. Defaults to None.
        max_results(int, optional): The maximum amount of data that can be contained in a single set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codestar.resource.list_all(ctx, project_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codestar.resource.list_all project_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codestar",
        operation="list_resources",
        op_kwargs={
            "projectId": project_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, rest_api_id: str, resource_id: str, http_method: str, status_code: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing MethodResponse resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the MethodResponse resource.
        http_method(str): [Required] The HTTP verb of the Method resource.
        status_code(str): [Required] The status code identifier for the MethodResponse resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.response.delete(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.response.delete rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_method_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
        },
    )


async def get(
    hub, ctx, rest_api_id: str, resource_id: str, http_method: str, status_code: str
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a MethodResponse resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the MethodResponse resource.
        http_method(str): [Required] The HTTP verb of the Method resource.
        status_code(str): [Required] The status code for the MethodResponse resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.response.get(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.response.get rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_method_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
        },
    )


async def put(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    status_code: str,
    response_parameters: Dict = None,
    response_models: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a MethodResponse to an existing Method resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the Method resource.
        http_method(str): [Required] The HTTP verb of the Method resource.
        status_code(str): [Required] The method response's status code.
        response_parameters(Dict, optional): A key-value map specifying required or optional response parameters that API Gateway can send back to the caller. A key defines a method response header name and the associated value is a Boolean flag indicating whether the method response parameter is required or not. The method response header names must match the pattern of method.response.header.{name}, where name is a valid and unique header name. The response parameter names defined here are available in the integration response to be mapped from an integration response header expressed in integration.response.header.{name}, a static value enclosed within a pair of single quotes (e.g., 'application/json'), or a JSON expression from the back-end response payload in the form of integration.response.body.{JSON-expression}, where JSON-expression is a valid JSON expression without the $ prefix.). Defaults to None.
        response_models(Dict, optional): Specifies the Model resources used for the response's content type. Response models are represented as a key/value map, with a content type as the key and a Model name as the value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.response.put(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.response.put rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="put_method_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
            "responseParameters": response_parameters,
            "responseModels": response_models,
        },
    )


async def update(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    status_code: str,
    patch_operations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing MethodResponse resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the MethodResponse resource.
        http_method(str): [Required] The HTTP verb of the Method resource.
        status_code(str): [Required] The status code for the MethodResponse resource.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.response.update(
                ctx, rest_api_id=value, resource_id=value, http_method=value, status_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.response.update rest_api_id=value, resource_id=value, http_method=value, status_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_method_response",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "statusCode": status_code,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    client_request_token: str,
    metadata: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Chime SDK messaging AppInstance under an AWS account. Only SDK messaging customers use this API. CreateAppInstance supports idempotency behavior as described in the AWS API Standard.

    Args:
        name(str): The name of the AppInstance.
        metadata(str, optional): The metadata of the AppInstance. Limited to a 1KB string in UTF-8. Defaults to None.
        client_request_token(str): The ClientRequestToken of the AppInstance.
        tags(List, optional): Tags assigned to the AppInstanceUser. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.init.create(
                ctx, name=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.init.create name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_app_instance",
        op_kwargs={
            "Name": name,
            "Metadata": metadata,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, app_instance_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an AppInstance and all associated data asynchronously.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.init.delete(ctx, app_instance_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.init.delete app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_app_instance",
        op_kwargs={"AppInstanceArn": app_instance_arn},
    )


async def describe(hub, ctx, app_instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the full details of an AppInstance.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.init.describe(ctx, app_instance_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.init.describe app_instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="describe_app_instance",
        op_kwargs={"AppInstanceArn": app_instance_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all Amazon Chime AppInstances created under a single AWS account.

    Args:
        max_results(int, optional): The maximum number of AppInstances that you want to return. Defaults to None.
        next_token(str, optional): The token passed by previous API requests until you reach the maximum number of AppInstances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_app_instances",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, app_instance_arn: str, name: str, metadata: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates AppInstance metadata.

    Args:
        app_instance_arn(str): The ARN of the AppInstance.
        name(str): The name that you want to change.
        metadata(str, optional): The metadata that you want to change. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.app_instance.init.update(
                ctx, app_instance_arn=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.app_instance.init.update app_instance_arn=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_app_instance",
        op_kwargs={
            "AppInstanceArn": app_instance_arn,
            "Name": name,
            "Metadata": metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, rest_api_id: str, resource_id: str, http_method: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing Method resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the Method resource.
        http_method(str): [Required] The HTTP verb of the Method resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.init.delete(
                ctx, rest_api_id=value, resource_id=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.init.delete rest_api_id=value, resource_id=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_method",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
        },
    )


async def get(hub, ctx, rest_api_id: str, resource_id: str, http_method: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe an existing Method resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the Method resource.
        http_method(str): [Required] Specifies the method request's HTTP method type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.init.get(
                ctx, rest_api_id=value, resource_id=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.init.get rest_api_id=value, resource_id=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_method",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
        },
    )


async def put(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    authorization_type: str,
    authorizer_id: str = None,
    api_key_required: bool = None,
    operation_name: str = None,
    request_parameters: Dict = None,
    request_models: Dict = None,
    request_validator_id: str = None,
    authorization_scopes: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Add a method to an existing Resource resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the new Method resource.
        http_method(str): [Required] Specifies the method request's HTTP method type.
        authorization_type(str): [Required] The method's authorization type. Valid values are NONE for open access, AWS_IAM for using AWS IAM permissions, CUSTOM for using a custom authorizer, or COGNITO_USER_POOLS for using a Cognito user pool.
        authorizer_id(str, optional): Specifies the identifier of an Authorizer to use on this Method, if the type is CUSTOM or COGNITO_USER_POOLS. The authorizer identifier is generated by API Gateway when you created the authorizer. Defaults to None.
        api_key_required(bool, optional): Specifies whether the method required a valid ApiKey. Defaults to None.
        operation_name(str, optional): A human-friendly operation identifier for the method. For example, you can assign the operationName of ListPets for the GET /pets method in the PetStore example. Defaults to None.
        request_parameters(Dict, optional): A key-value map defining required or optional method request parameters that can be accepted by API Gateway. A key defines a method request parameter name matching the pattern of method.request.{location}.{name}, where location is querystring, path, or header and name is a valid and unique parameter name. The value associated with the key is a Boolean flag indicating whether the parameter is required (true) or optional (false). The method request parameter names defined here are available in Integration to be mapped to integration request parameters or body-mapping templates. Defaults to None.
        request_models(Dict, optional): Specifies the Model resources used for the request's content type. Request models are represented as a key/value map, with a content type as the key and a Model name as the value. Defaults to None.
        request_validator_id(str, optional): The identifier of a RequestValidator for validating the method request. Defaults to None.
        authorization_scopes(List, optional): A list of authorization scopes configured on the method. The scopes are used with a COGNITO_USER_POOLS authorizer to authorize the method invocation. The authorization works by matching the method scopes against the scopes parsed from the access token in the incoming request. The method invocation is authorized if any method scopes matches a claimed scope in the access token. Otherwise, the invocation is not authorized. When the method scope is configured, the client must provide an access token instead of an identity token for authorization purposes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.init.put(
                ctx,
                rest_api_id=value,
                resource_id=value,
                http_method=value,
                authorization_type=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.init.put rest_api_id=value, resource_id=value, http_method=value, authorization_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="put_method",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "authorizationType": authorization_type,
            "authorizerId": authorizer_id,
            "apiKeyRequired": api_key_required,
            "operationName": operation_name,
            "requestParameters": request_parameters,
            "requestModels": request_models,
            "requestValidatorId": request_validator_id,
            "authorizationScopes": authorization_scopes,
        },
    )


async def update(
    hub,
    ctx,
    rest_api_id: str,
    resource_id: str,
    http_method: str,
    patch_operations: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Method resource.

    Args:
        rest_api_id(str): [Required] The string identifier of the associated RestApi.
        resource_id(str): [Required] The Resource identifier for the Method resource.
        http_method(str): [Required] The HTTP verb of the Method resource.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.method.init.update(
                ctx, rest_api_id=value, resource_id=value, http_method=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.method.init.update rest_api_id=value, resource_id=value, http_method=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_method",
        op_kwargs={
            "restApiId": rest_api_id,
            "resourceId": resource_id,
            "httpMethod": http_method,
            "patchOperations": patch_operations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    client_request_token: str,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a gateway group with the specified details.

    Args:
        name(str): The name of the gateway group.
        description(str, optional): The description of the gateway group. Defaults to None.
        client_request_token(str):  A unique, user-specified identifier for the request that ensures idempotency.
        tags(List, optional): The tags to be added to the specified resource. Do not provide system tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.group.create(
                ctx, name=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.group.create name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="create_gateway_group",
        op_kwargs={
            "Name": name,
            "Description": description,
            "ClientRequestToken": client_request_token,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, gateway_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a gateway group.

    Args:
        gateway_group_arn(str): The ARN of the gateway group to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.group.delete(
                ctx, gateway_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.group.delete gateway_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="delete_gateway_group",
        op_kwargs={"GatewayGroupArn": gateway_group_arn},
    )


async def get(hub, ctx, gateway_group_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details of a gateway group.

    Args:
        gateway_group_arn(str): The ARN of the gateway group to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.group.get(ctx, gateway_group_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.group.get gateway_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_gateway_group",
        op_kwargs={"GatewayGroupArn": gateway_group_arn},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of gateway group summaries. Use GetGatewayGroup to retrieve details of a specific gateway group.

    Args:
        next_token(str, optional): The token used to paginate though multiple pages of gateway group summaries. Defaults to None.
        max_results(int, optional): The maximum number of gateway group summaries to return. The default is 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_gateway_groups",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(
    hub, ctx, gateway_group_arn: str, name: str = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details of a gateway group. If any optional field is not provided, the existing corresponding value is left unmodified.

    Args:
        gateway_group_arn(str): The ARN of the gateway group to update.
        name(str, optional): The updated name of the gateway group. Defaults to None.
        description(str, optional): The updated description of the gateway group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.group.update(
                ctx, gateway_group_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.group.update gateway_group_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_gateway_group",
        op_kwargs={
            "GatewayGroupArn": gateway_group_arn,
            "Name": name,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub, ctx, detector_id: str, finding_types: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Generates example findings of types specified by the list of finding types. If 'NULL' is specified for findingTypes, the API generates example findings of all supported finding types.

    Args:
        detector_id(str): The ID of the detector to create sample findings for.
        finding_types(List, optional): The types of sample findings to generate. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.sample_finding.create_multiple(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.sample_finding.create_multiple detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="create_sample_findings",
        op_kwargs={"DetectorId": detector_id, "FindingTypes": finding_types},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    scaling_plan_name: str,
    scaling_plan_version: int,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the scalable resources in the specified scaling plan.

    Args:
        scaling_plan_name(str): The name of the scaling plan.
        scaling_plan_version(int): The version number of the scaling plan. Currently, the only valid value is 1.
        max_results(int, optional): The maximum number of scalable resources to return. The value must be between 1 and 50. The default value is 50. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling_plan_scaling_plan.resource.init.describe_all(
                ctx, scaling_plan_name=value, scaling_plan_version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling_plan_scaling_plan.resource.init.describe_all scaling_plan_name=value, scaling_plan_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling-plans",
        operation="describe_scaling_plan_resources",
        op_kwargs={
            "ScalingPlanName": scaling_plan_name,
            "ScalingPlanVersion": scaling_plan_version,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    layer_name: str,
    version_number: int,
    statement_id: str,
    action: str,
    principal: str,
    organization_id: str = None,
    revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds permissions to the resource-based policy of a version of an Lambda layer. Use this action to grant layer usage permission to other accounts. You can grant permission to a single account, all accounts in an organization, or all Amazon Web Services accounts.  To revoke permission, call RemoveLayerVersionPermission with the statement ID that you specified when you added it.

    Args:
        layer_name(str): The name or Amazon Resource Name (ARN) of the layer.
        version_number(int): The version number.
        statement_id(str): An identifier that distinguishes the policy from others on the same layer version.
        action(str): The API action that grants access to the layer. For example, lambda:GetLayerVersion.
        principal(str): An account ID, or * to grant layer usage permission to all accounts in an organization, or all Amazon Web Services accounts (if organizationId is not specified). For the last case, make sure that you really do want all Amazon Web Services accounts to have usage permission to this layer. .
        organization_id(str, optional): With the principal set to *, grant permission to all accounts in the specified organization. Defaults to None.
        revision_id(str, optional): Only update the policy if the revision ID matches the ID specified. Use this option to avoid modifying a policy that has changed since you last read it. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.permission.add(
                ctx,
                layer_name=value,
                version_number=value,
                statement_id=value,
                action=value,
                principal=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.permission.add layer_name=value, version_number=value, statement_id=value, action=value, principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="add_layer_version_permission",
        op_kwargs={
            "LayerName": layer_name,
            "VersionNumber": version_number,
            "StatementId": statement_id,
            "Action": action,
            "Principal": principal,
            "OrganizationId": organization_id,
            "RevisionId": revision_id,
        },
    )


async def remove(
    hub,
    ctx,
    layer_name: str,
    version_number: int,
    statement_id: str,
    revision_id: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Removes a statement from the permissions policy for a version of an Lambda layer. For more information, see AddLayerVersionPermission.

    Args:
        layer_name(str): The name or Amazon Resource Name (ARN) of the layer.
        version_number(int): The version number.
        statement_id(str): The identifier that was specified when the statement was added.
        revision_id(str, optional): Only update the policy if the revision ID matches the ID specified. Use this option to avoid modifying a policy that has changed since you last read it. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.permission.remove(
                ctx, layer_name=value, version_number=value, statement_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.permission.remove layer_name=value, version_number=value, statement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="remove_layer_version_permission",
        op_kwargs={
            "LayerName": layer_name,
            "VersionNumber": version_number,
            "StatementId": statement_id,
            "RevisionId": revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def accept(
    hub, ctx, qualification_request_id: str, integer_value: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     The AcceptQualificationRequest operation approves a Worker's request for a Qualification.   Only the owner of the Qualification type can grant a Qualification request for that type.   A successful request for the AcceptQualificationRequest operation returns with no errors and an empty body.

    Args:
        qualification_request_id(str): The ID of the Qualification request, as returned by the GetQualificationRequests operation.
        integer_value(int, optional):  The value of the Qualification. You can omit this value if you are using the presence or absence of the Qualification as the basis for a HIT requirement. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.request.accept(
                ctx, qualification_request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.request.accept qualification_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="accept_qualification_request",
        op_kwargs={
            "QualificationRequestId": qualification_request_id,
            "IntegerValue": integer_value,
        },
    )


async def list_all(
    hub,
    ctx,
    qualification_type_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ListQualificationRequests operation retrieves requests for Qualifications of a particular Qualification type. The owner of the Qualification type calls this operation to poll for pending requests, and accepts them using the AcceptQualification operation.

    Args:
        qualification_type_id(str, optional): The ID of the QualificationType. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Mechanical Turk returns a pagination token in the response. You can use this pagination token to retrieve the next set of results. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return in a single call. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.request.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.request.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="list_qualification_requests",
        op_kwargs={
            "QualificationTypeId": qualification_type_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def reject(hub, ctx, qualification_request_id: str, reason: str = None) -> Dict:
    r"""
    **Autogenerated function**

     The RejectQualificationRequest operation rejects a user's request for a Qualification.   You can provide a text message explaining why the request was rejected. The Worker who made the request can see this message.

    Args:
        qualification_request_id(str):  The ID of the Qualification request, as returned by the ListQualificationRequests operation. .
        reason(str, optional): A text message explaining why the request was rejected, to be shown to the Worker who made the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.qualification.request.reject(
                ctx, qualification_request_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.qualification.request.reject qualification_request_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="reject_qualification_request",
        op_kwargs={
            "QualificationRequestId": qualification_request_id,
            "Reason": reason,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    instance_names: List,
    availability_zone: str,
    blueprint_id: str,
    bundle_id: str,
    custom_image_name: str = None,
    user_data: str = None,
    key_pair_name: str = None,
    tags: List = None,
    add_ons: List = None,
    ip_address_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more Amazon Lightsail instances. The create instances operation supports tag-based access control via request tags. For more information, see the Lightsail Developer Guide.

    Args:
        instance_names(List): The names to use for your new Lightsail instances. Separate multiple values using quotation marks and commas, for example: ["MyFirstInstance","MySecondInstance"] .
        availability_zone(str): The Availability Zone in which to create your instance. Use the following format: us-east-2a (case sensitive). You can get a list of Availability Zones by using the get regions operation. Be sure to add the include Availability Zones parameter to your request.
        custom_image_name(str, optional): (Deprecated) The name for your custom image.  In releases prior to June 12, 2017, this parameter was ignored by the API. It is now deprecated. . Defaults to None.
        blueprint_id(str): The ID for a virtual private server image (e.g., app_wordpress_4_4 or app_lamp_7_0). Use the get blueprints operation to return a list of available images (or blueprints).  Use active blueprints when creating new instances. Inactive blueprints are listed to support customers with existing instances and are not necessarily available to create new instances. Blueprints are marked inactive when they become outdated due to operating system updates or new application releases. .
        bundle_id(str): The bundle of specification information for your virtual private server (or instance), including the pricing plan (e.g., micro_1_0).
        user_data(str, optional): A launch script you can create that configures a server with additional user data. For example, you might want to run apt-get -y update.  Depending on the machine image you choose, the command to get software on your instance varies. Amazon Linux and CentOS use yum, Debian and Ubuntu use apt-get, and FreeBSD uses pkg. For a complete list, see the Amazon Lightsail Developer Guide. . Defaults to None.
        key_pair_name(str, optional): The name of your key pair. Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.
        add_ons(List, optional): An array of objects representing the add-ons to enable for the new instance. Defaults to None.
        ip_address_type(str, optional): The IP address type for the instance. The possible values are ipv4 for IPv4 only, and dualstack for IPv4 and IPv6. The default value is dualstack. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.init.create_multiple(
                ctx,
                instance_names=value,
                availability_zone=value,
                blueprint_id=value,
                bundle_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.init.create_multiple instance_names=value, availability_zone=value, blueprint_id=value, bundle_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_instances",
        op_kwargs={
            "instanceNames": instance_names,
            "availabilityZone": availability_zone,
            "customImageName": custom_image_name,
            "blueprintId": blueprint_id,
            "bundleId": bundle_id,
            "userData": user_data,
            "keyPairName": key_pair_name,
            "tags": tags,
            "addOns": add_ons,
            "ipAddressType": ip_address_type,
        },
    )


async def delete(
    hub, ctx, instance_name: str, force_delete_add_ons: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an Amazon Lightsail instance. The delete instance operation supports tag-based access control via resource tags applied to the resource identified by instance name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_name(str): The name of the instance to delete.
        force_delete_add_ons(bool, optional): A Boolean value to indicate whether to delete the enabled add-ons for the disk. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.init.delete(ctx, instance_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.init.delete instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_instance",
        op_kwargs={
            "instanceName": instance_name,
            "forceDeleteAddOns": force_delete_add_ons,
        },
    )


async def get(hub, ctx, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific Amazon Lightsail instance, which is a virtual private server.

    Args:
        instance_name(str): The name of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.init.get(ctx, instance_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.init.get instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_instance",
        op_kwargs={"instanceName": instance_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all Amazon Lightsail virtual private servers, or instances.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetInstances request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_instances",
        op_kwargs={"pageToken": page_token},
    )


async def reboot(hub, ctx, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Restarts a specific instance. The reboot instance operation supports tag-based access control via resource tags applied to the resource identified by instance name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_name(str): The name of the instance to reboot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.init.reboot(ctx, instance_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.init.reboot instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="reboot_instance",
        op_kwargs={"instanceName": instance_name},
    )


async def start(hub, ctx, instance_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a specific Amazon Lightsail instance from a stopped state. To restart an instance, use the reboot instance operation.  When you start a stopped instance, Lightsail assigns a new public IP address to the instance. To use the same IP address after stopping and starting an instance, create a static IP address and attach it to the instance. For more information, see the Amazon Lightsail Developer Guide.  The start instance operation supports tag-based access control via resource tags applied to the resource identified by instance name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_name(str): The name of the instance (a virtual private server) to start.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.init.start(ctx, instance_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.init.start instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="start_instance",
        op_kwargs={"instanceName": instance_name},
    )


async def stop(hub, ctx, instance_name: str, force: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Stops a specific Amazon Lightsail instance that is currently running.  When you start a stopped instance, Lightsail assigns a new public IP address to the instance. To use the same IP address after stopping and starting an instance, create a static IP address and attach it to the instance. For more information, see the Amazon Lightsail Developer Guide.  The stop instance operation supports tag-based access control via resource tags applied to the resource identified by instance name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        instance_name(str): The name of the instance (a virtual private server) to stop.
        force(bool, optional): When set to True, forces a Lightsail instance that is stuck in a stopping state to stop.  Only use the force parameter if your instance is stuck in the stopping state. In any other state, your instance should stop normally without adding this parameter to your API request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.instance.init.stop(ctx, instance_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.instance.init.stop instance_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="stop_instance",
        op_kwargs={"instanceName": instance_name, "force": force},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(hub, ctx, load_balancer_name: str, listeners: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates one or more listeners for the specified load balancer. If a listener with the specified port does not already exist, it is created; otherwise, the properties of the new listener must match the properties of the existing listener. For more information, see Listeners for Your Classic Load Balancer in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        listeners(List): The listeners.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.listener.init.create_multiple(
                ctx, load_balancer_name=value, listeners=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.listener.init.create_multiple load_balancer_name=value, listeners=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="create_load_balancer_listeners",
        op_kwargs={"LoadBalancerName": load_balancer_name, "Listeners": listeners},
    )


async def delete_multiple(
    hub, ctx, load_balancer_name: str, load_balancer_ports: List
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified listeners from the specified load balancer.

    Args:
        load_balancer_name(str): The name of the load balancer.
        load_balancer_ports(List): The client port numbers of the listeners.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.listener.init.delete_multiple(
                ctx, load_balancer_name=value, load_balancer_ports=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.listener.init.delete_multiple load_balancer_name=value, load_balancer_ports=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="delete_load_balancer_listeners",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "LoadBalancerPorts": load_balancer_ports,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    package_cleanup: bool = None,
    exclude_app_packages_from_cleanup: List = None,
    reboot_after_use: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a profile that can be applied to one or more private fleet device instances.

    Args:
        name(str): The name of your instance profile.
        description(str, optional): The description of your instance profile. Defaults to None.
        package_cleanup(bool, optional): When set to true, Device Farm removes app packages after a test run. The default value is false for private devices. Defaults to None.
        exclude_app_packages_from_cleanup(List, optional): An array of strings that specifies the list of app packages that should not be cleaned up from the device after a test run. The list of packages is considered only if you set packageCleanup to true. Defaults to None.
        reboot_after_use(bool, optional): When set to true, Device Farm reboots the instance after a test run. The default value is true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.instance_profile.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.instance_profile.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_instance_profile",
        op_kwargs={
            "name": name,
            "description": description,
            "packageCleanup": package_cleanup,
            "excludeAppPackagesFromCleanup": exclude_app_packages_from_cleanup,
            "rebootAfterUse": reboot_after_use,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a profile that can be applied to one or more private device instances.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the instance profile you are requesting to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.instance_profile.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.instance_profile.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_instance_profile",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified instance profile.

    Args:
        arn(str): The Amazon Resource Name (ARN) of an instance profile.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.instance_profile.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.instance_profile.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_instance_profile",
        op_kwargs={"arn": arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all the instance profiles in an AWS account.

    Args:
        max_results(int, optional): An integer that specifies the maximum number of items you want to return in the API response. Defaults to None.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.instance_profile.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.instance_profile.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_instance_profiles",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub,
    ctx,
    arn: str,
    name: str = None,
    description: str = None,
    package_cleanup: bool = None,
    exclude_app_packages_from_cleanup: List = None,
    reboot_after_use: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates information about an existing private device instance profile.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the instance profile.
        name(str, optional): The updated name for your instance profile. Defaults to None.
        description(str, optional): The updated description for your instance profile. Defaults to None.
        package_cleanup(bool, optional): The updated choice for whether you want to specify package cleanup. The default value is false for private devices. Defaults to None.
        exclude_app_packages_from_cleanup(List, optional): An array of strings that specifies the list of app packages that should not be cleaned up from the device after a test run is over. The list of packages is only considered if you set packageCleanup to true. Defaults to None.
        reboot_after_use(bool, optional): The updated choice for whether you want to reboot the device after use. The default value is true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.instance_profile.update(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.instance_profile.update arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="update_instance_profile",
        op_kwargs={
            "arn": arn,
            "name": name,
            "description": description,
            "packageCleanup": package_cleanup,
            "excludeAppPackagesFromCleanup": exclude_app_packages_from_cleanup,
            "rebootAfterUse": reboot_after_use,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    account_id: str,
    job_id: str,
    requested_job_status: str,
    status_update_reason: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the status for the specified job. Use this action to confirm that you want to run a job or to cancel an existing job. For more information, see S3 Batch Operations in the Amazon S3 User Guide.  Related actions include:    CreateJob     ListJobs     DescribeJob     UpdateJobStatus

    Args:
        account_id(str): The account ID associated with the S3 Batch Operations job.
        job_id(str): The ID of the job whose status you want to update.
        requested_job_status(str): The status that you want to move the specified job to.
        status_update_reason(str, optional): A description of the reason why you want to change the specified job's status. This field can be any string up to the maximum length. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.job.status.update(
                ctx, account_id=value, job_id=value, requested_job_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.job.status.update account_id=value, job_id=value, requested_job_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="update_job_status",
        op_kwargs={
            "AccountId": account_id,
            "JobId": job_id,
            "RequestedJobStatus": requested_job_status,
            "StatusUpdateReason": status_update_reason,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(hub, ctx, check_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the refresh status of the AWS Trusted Advisor checks that have the specified check IDs. You can get the check IDs by calling the DescribeTrustedAdvisorChecks operation. Some checks are refreshed automatically, and you can't return their refresh statuses by using the DescribeTrustedAdvisorCheckRefreshStatuses operation. If you call this operation for these checks, you might see an InvalidParameterValue error.    You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        check_ids(List): The IDs of the Trusted Advisor checks to get the status.  If you specify the check ID of a check that is automatically refreshed, you might see an InvalidParameterValue error. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.trusted_advisor_check.refresh_status.describe_all(
                ctx, check_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.trusted_advisor_check.refresh_status.describe_all check_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="describe_trusted_advisor_check_refresh_statuses",
        op_kwargs={"checkIds": check_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    component_version_arn: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the list of component build versions for the specified semantic version.  The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.  Filtering: When you retrieve or reference a resource with a semantic version, you can use wildcards (x) to filter your results. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards. For example, specifying "1.2.x", or "1.x.x" works to filter list results, but neither "1.x.2", nor "x.2.x" will work. You do not have to specify the build - Image Builder automatically uses a wildcard for that, if applicable.

    Args:
        component_version_arn(str): The component version Amazon Resource Name (ARN) whose versions you want to list.
        max_results(int, optional): The maximum items to return in a request. Defaults to None.
        next_token(str, optional): A token to specify where to start paginating. This is the NextToken from a previously truncated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.component.build_version.list_all(
                ctx, component_version_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.component.build_version.list_all component_version_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="list_component_build_versions",
        op_kwargs={
            "componentVersionArn": component_version_arn,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    flow_definition_name: str,
    human_loop_config: Dict,
    output_config: Dict,
    role_arn: str,
    human_loop_request_source: Dict = None,
    human_loop_activation_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a flow definition.

    Args:
        flow_definition_name(str): The name of your flow definition.
        human_loop_request_source(Dict, optional): Container for configuring the source of human task requests. Use to specify if Amazon Rekognition or Amazon Textract is used as an integration source. Defaults to None.
        human_loop_activation_config(Dict, optional): An object containing information about the events that trigger a human workflow. Defaults to None.
        human_loop_config(Dict): An object containing information about the tasks the human reviewers will perform.
        output_config(Dict): An object containing information about where the human review results will be uploaded.
        role_arn(str): The Amazon Resource Name (ARN) of the role needed to call other services on your behalf. For example, arn:aws:iam::1234567890:role/service-role/AmazonSageMaker-ExecutionRole-20180111T151298.
        tags(List, optional): An array of key-value pairs that contain metadata to help you categorize and organize a flow definition. Each tag consists of a key and a value, both of which you define. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.flow_definition.create(
                ctx,
                flow_definition_name=value,
                human_loop_config=value,
                output_config=value,
                role_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.flow_definition.create flow_definition_name=value, human_loop_config=value, output_config=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_flow_definition",
        op_kwargs={
            "FlowDefinitionName": flow_definition_name,
            "HumanLoopRequestSource": human_loop_request_source,
            "HumanLoopActivationConfig": human_loop_activation_config,
            "HumanLoopConfig": human_loop_config,
            "OutputConfig": output_config,
            "RoleArn": role_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, flow_definition_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified flow definition.

    Args:
        flow_definition_name(str): The name of the flow definition you are deleting.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.flow_definition.delete(
                ctx, flow_definition_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.flow_definition.delete flow_definition_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_flow_definition",
        op_kwargs={"FlowDefinitionName": flow_definition_name},
    )


async def describe(hub, ctx, flow_definition_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the specified flow definition.

    Args:
        flow_definition_name(str): The name of the flow definition.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.flow_definition.describe(
                ctx, flow_definition_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.flow_definition.describe flow_definition_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_flow_definition",
        op_kwargs={"FlowDefinitionName": flow_definition_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the flow definitions in your account.

    Args:
        creation_time_after(str, optional): A filter that returns only flow definitions with a creation time greater than or equal to the specified timestamp. Defaults to None.
        creation_time_before(str, optional): A filter that returns only flow definitions that were created before the specified timestamp. Defaults to None.
        sort_order(str, optional): An optional value that specifies whether you want the results sorted in Ascending or Descending order. Defaults to None.
        next_token(str, optional): A token to resume pagination. Defaults to None.
        max_results(int, optional): The total number of items to return. If the total number of available items is more than the value specified in MaxResults, then a NextToken will be provided in the output that you can use to resume pagination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.flow_definition.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.flow_definition.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_flow_definitions",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, saml_metadata_document: str, name: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an IAM resource that describes an identity provider (IdP) that supports SAML 2.0. The SAML provider resource that you create with this operation can be used as a principal in an IAM role's trust policy. Such a policy can enable federated users who sign in using the SAML IdP to assume the role. You can create an IAM role that supports Web-based single sign-on (SSO) to the Management Console or one that supports API access to Amazon Web Services. When you create the SAML provider resource, you upload a SAML metadata document that you get from your IdP. That document includes the issuer's name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that the IdP sends. You must generate the metadata document using the identity management software that is used as your organization's IdP.   This operation requires Signature Version 4.   For more information, see Enabling SAML 2.0 federated users to access the Management Console and About SAML 2.0-based federation in the IAM User Guide.

    Args:
        saml_metadata_document(str): An XML document generated by an identity provider (IdP) that supports SAML 2.0. The document includes the issuer's name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that are received from the IdP. You must generate the metadata document using the identity management software that is used as your organization's IdP. For more information, see About SAML 2.0-based federation in the IAM User Guide .
        name(str): The name of the provider to create. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tags(List, optional): A list of tags that you want to attach to the new IAM SAML provider. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.  If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.saml_provider.init.create(
                ctx, saml_metadata_document=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.saml_provider.init.create saml_metadata_document=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_saml_provider",
        op_kwargs={
            "SAMLMetadataDocument": saml_metadata_document,
            "Name": name,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, saml_provider_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a SAML provider resource in IAM. Deleting the provider resource from IAM does not update any roles that reference the SAML provider resource's ARN as a principal in their trust policies. Any attempt to assume a role that references a non-existent provider resource ARN fails.   This operation requires Signature Version 4.

    Args:
        saml_provider_arn(str): The Amazon Resource Name (ARN) of the SAML provider to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.saml_provider.init.delete(ctx, saml_provider_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.saml_provider.init.delete saml_provider_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_saml_provider",
        op_kwargs={"SAMLProviderArn": saml_provider_arn},
    )


async def get(hub, ctx, saml_provider_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the SAML provider metadocument that was uploaded when the IAM SAML provider resource object was created or updated.  This operation requires Signature Version 4.

    Args:
        saml_provider_arn(str): The Amazon Resource Name (ARN) of the SAML provider resource object in IAM to get information about. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.saml_provider.init.get(ctx, saml_provider_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.saml_provider.init.get saml_provider_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_saml_provider",
        op_kwargs={"SAMLProviderArn": saml_provider_arn},
    )


async def list_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Lists the SAML provider resource objects defined in IAM in the account. IAM resource-listing operations return a subset of the available attributes for the resource. For example, this operation does not return tags, even though they are an attribute of the returned object. To view all of the information for a SAML provider, see GetSAMLProvider.   This operation requires Signature Version 4.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.saml_provider.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.saml_provider.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iam", operation="list_saml_providers", op_kwargs={}
    )


async def tag(hub, ctx, saml_provider_arn: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags to a Security Assertion Markup Language (SAML) identity provider. For more information about these providers, see About SAML 2.0-based federation . If a tag with the same key name already exists, then that tag is overwritten with the new value. A tag consists of a key name and an associated value. By assigning tags to your resources, you can do the following:    Administrative grouping and discovery - Attach tags to resources to aid in organization and search. For example, you could search for all resources with the key name Project and the value MyImportantProject. Or search for all resources with the key name Cost Center and the value 41200.     Access control - Include tags in IAM user-based and resource-based policies. You can use tags to restrict access to only a SAML identity provider that has a specified tag attached. For examples of policies that show how to use tags to control access, see Control access using IAM tags in the IAM User Guide.      If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. For more information about tagging, see Tagging IAM resources in the IAM User Guide.   Amazon Web Services always interprets the tag Value as a single string. If you need to store an array, you can store comma-separated values in the string. However, you must interpret the value in your code.

    Args:
        saml_provider_arn(str): The ARN of the SAML identity provider in IAM to which you want to add tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tags(List): The list of tags that you want to attach to the SAML identity provider in IAM. Each tag consists of a key name and an associated value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.saml_provider.init.tag(
                ctx, saml_provider_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.saml_provider.init.tag saml_provider_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="tag_saml_provider",
        op_kwargs={"SAMLProviderArn": saml_provider_arn, "Tags": tags},
    )


async def untag(hub, ctx, saml_provider_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified tags from the specified Security Assertion Markup Language (SAML) identity provider in IAM. For more information about these providers, see About web identity federation. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

    Args:
        saml_provider_arn(str): The ARN of the SAML identity provider in IAM from which you want to remove tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tag_keys(List): A list of key names as a simple array of strings. The tags with matching keys are removed from the specified SAML identity provider.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.saml_provider.init.untag(
                ctx, saml_provider_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.saml_provider.init.untag saml_provider_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="untag_saml_provider",
        op_kwargs={"SAMLProviderArn": saml_provider_arn, "TagKeys": tag_keys},
    )


async def update(hub, ctx, saml_metadata_document: str, saml_provider_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the metadata document for an existing SAML provider resource object.  This operation requires Signature Version 4.

    Args:
        saml_metadata_document(str): An XML document generated by an identity provider (IdP) that supports SAML 2.0. The document includes the issuer's name, expiration information, and keys that can be used to validate the SAML authentication response (assertions) that are received from the IdP. You must generate the metadata document using the identity management software that is used as your organization's IdP.
        saml_provider_arn(str): The Amazon Resource Name (ARN) of the SAML provider to update. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.saml_provider.init.update(
                ctx, saml_metadata_document=value, saml_provider_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.saml_provider.init.update saml_metadata_document=value, saml_provider_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_saml_provider",
        op_kwargs={
            "SAMLMetadataDocument": saml_metadata_document,
            "SAMLProviderArn": saml_provider_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, checksum: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of an intent based on the $LATEST version of the intent. If the $LATEST version of this intent hasn't changed since you last updated it, Amazon Lex doesn't create a new version. It returns the last version you created.  You can update only the $LATEST version of the intent. You can't update the numbered versions that you create with the CreateIntentVersion operation.   When you create a version of an intent, Amazon Lex sets the version to 1. Subsequent versions increment by 1. For more information, see versioning-intro.  This operation requires permissions to perform the lex:CreateIntentVersion action.

    Args:
        name(str): The name of the intent that you want to create a new version of. The name is case sensitive. .
        checksum(str, optional): Checksum of the $LATEST version of the intent that should be used to create the new version. If you specify a checksum and the $LATEST version of the intent has a different checksum, Amazon Lex returns a PreconditionFailedException exception and doesn't publish a new version. If you don't specify a checksum, Amazon Lex publishes the $LATEST version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.intent.version.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.intent.version.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="create_intent_version",
        op_kwargs={"name": name, "checksum": checksum},
    )


async def delete(hub, ctx, name: str, version: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specific version of an intent. To delete all versions of a intent, use the DeleteIntent operation.  This operation requires permissions for the lex:DeleteIntentVersion action.

    Args:
        name(str): The name of the intent.
        version(str): The version of the intent to delete. You cannot delete the $LATEST version of the intent. To delete the $LATEST version, use the DeleteIntent operation.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.intent.version.delete(ctx, name=value, version=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.intent.version.delete name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="delete_intent_version",
        op_kwargs={"name": name, "version": version},
    )


async def get_all(
    hub, ctx, name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about all of the versions of an intent. The GetIntentVersions operation returns an IntentMetadata object for each version of an intent. For example, if an intent has three numbered versions, the GetIntentVersions operation returns four IntentMetadata objects in the response, one for each numbered version and one for the $LATEST version.  The GetIntentVersions operation always returns at least one version, the $LATEST version. This operation requires permissions for the lex:GetIntentVersions action.

    Args:
        name(str): The name of the intent for which versions should be returned.
        next_token(str, optional): A pagination token for fetching the next page of intent versions. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of versions, specify the pagination token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of intent versions to return in the response. The default is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.intent.version.get_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.intent.version.get_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_intent_versions",
        op_kwargs={"name": name, "nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    template_id: str,
    source_entity: Dict,
    name: str = None,
    permissions: List = None,
    tags: List = None,
    version_description: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a template from an existing Amazon QuickSight analysis or template. You can use the resulting template to create a dashboard. A template is an entity in QuickSight that encapsulates the metadata required to create an analysis and that you can use to create s dashboard. A template adds a layer of abstraction by using placeholders to replace the dataset associated with the analysis. You can use templates to create dashboards by replacing dataset placeholders with datasets that follow the same schema that was used to create the source analysis and template.

    Args:
        aws_account_id(str): The ID for the Amazon Web Services account; that the group is in. Currently, you use the ID for the Amazon Web Services account; that contains your Amazon QuickSight account.
        template_id(str): An ID for the template that you want to create. This template is unique per Region; in each Amazon Web Services account;.
        name(str, optional): A display name for the template. Defaults to None.
        permissions(List, optional): A list of resource permissions to be set on the template. . Defaults to None.
        source_entity(Dict): The entity that you are using as a source when you create the template. In SourceEntity, you specify the type of object you're using as source: SourceTemplate for a template or SourceAnalysis for an analysis. Both of these require an Amazon Resource Name (ARN). For SourceTemplate, specify the ARN of the source template. For SourceAnalysis, specify the ARN of the source analysis. The SourceTemplate ARN can contain any Amazon Web Services account; and any QuickSight-supported Region;.  Use the DataSetReferences entity within SourceTemplate or SourceAnalysis to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. .
        tags(List, optional): Contains a map of the key-value pairs for the resource tag or tags assigned to the resource. Defaults to None.
        version_description(str, optional): A description of the current template version being created. This API operation creates the first version of the template. Every time UpdateTemplate is called, a new version is created. Each version of the template maintains a description of the version in the VersionDescription field. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.init.create(
                ctx, aws_account_id=value, template_id=value, source_entity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.init.create aws_account_id=value, template_id=value, source_entity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_template",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "Name": name,
            "Permissions": permissions,
            "SourceEntity": source_entity,
            "Tags": tags,
            "VersionDescription": version_description,
        },
    )


async def delete(
    hub, ctx, aws_account_id: str, template_id: str, version_number: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a template.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the template that you're deleting.
        template_id(str): An ID for the template you want to delete.
        version_number(int, optional): Specifies the version of the template that you want to delete. If you don't provide a version number, DeleteTemplate deletes all versions of the template. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.init.delete(
                ctx, aws_account_id=value, template_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.init.delete aws_account_id=value, template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_template",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "VersionNumber": version_number,
        },
    )


async def describe(
    hub,
    ctx,
    aws_account_id: str,
    template_id: str,
    version_number: int = None,
    alias_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a template's metadata.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the template that you're describing.
        template_id(str): The ID for the template.
        version_number(int, optional): (Optional) The number for the version to describe. If a VersionNumber parameter value isn't provided, the latest version of the template is described. Defaults to None.
        alias_name(str, optional): The alias of the template that you want to describe. If you name a specific alias, you describe the version that the alias points to. You can specify the latest version of the template by providing the keyword $LATEST in the AliasName parameter. The keyword $PUBLISHED doesn't apply to templates. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.init.describe(
                ctx, aws_account_id=value, template_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.init.describe aws_account_id=value, template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_template",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "VersionNumber": version_number,
            "AliasName": alias_name,
        },
    )


async def list_all(
    hub, ctx, aws_account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the templates in the current Amazon QuickSight account.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the templates that you're listing.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.init.list_all(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.init.list_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_templates",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    aws_account_id: str,
    template_id: str,
    source_entity: Dict,
    version_description: str = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a template from an existing Amazon QuickSight analysis or another template.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the template that you're updating.
        template_id(str): The ID for the template.
        source_entity(Dict): The entity that you are using as a source when you update the template. In SourceEntity, you specify the type of object you're using as source: SourceTemplate for a template or SourceAnalysis for an analysis. Both of these require an Amazon Resource Name (ARN). For SourceTemplate, specify the ARN of the source template. For SourceAnalysis, specify the ARN of the source analysis. The SourceTemplate ARN can contain any Amazon Web Services account; and any QuickSight-supported Region;.  Use the DataSetReferences entity within SourceTemplate or SourceAnalysis to list the replacement datasets for the placeholders listed in the original. The schema in each dataset must match its placeholder. .
        version_description(str, optional): A description of the current template version that is being updated. Every time you call UpdateTemplate, you create a new version of the template. Each version of the template maintains a description of the version in the VersionDescription field. Defaults to None.
        name(str, optional): The name for the template. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.template.init.update(
                ctx, aws_account_id=value, template_id=value, source_entity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.template.init.update aws_account_id=value, template_id=value, source_entity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_template",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "TemplateId": template_id,
            "SourceEntity": source_entity,
            "VersionDescription": version_description,
            "Name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the request payment configuration of a bucket. To use this version of the operation, you must be the bucket owner. For more information, see Requester Pays Buckets. The following operations are related to GetBucketRequestPayment:    ListObjects

    Args:
        bucket(str): The name of the bucket for which to get the payment request configuration.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.request_payment.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.request_payment.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_request_payment",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    request_payment_configuration: Dict,
    content_md5: str = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Sets the request payment configuration for a bucket. By default, the bucket owner pays for downloads from the bucket. This configuration parameter enables the bucket owner (only) to specify that the person requesting the download will be charged for the download. For more information, see Requester Pays Buckets. The following operations are related to PutBucketRequestPayment:    CreateBucket     GetBucketRequestPayment

    Args:
        bucket(str): The bucket name.
        content_md5(str, optional): The base64-encoded 128-bit MD5 digest of the data. You must use this header as a message integrity check to verify that the request body was not corrupted in transit. For more information, see RFC 1864. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        request_payment_configuration(Dict): Container for Payer.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.request_payment.put(
                ctx, bucket=value, request_payment_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.request_payment.put bucket=value, request_payment_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_request_payment",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "RequestPaymentConfiguration": request_payment_configuration,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    resource_arn: str,
    statement_id: str,
    effect: str,
    principal: List,
    action: List,
    condition: Dict = None,
    expected_revision_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a new resource policy statement to a bot or bot alias. If a resource policy exists, the statement is added to the current resource policy. If a policy doesn't exist, a new policy is created. You can't create a resource policy statement that allows cross-account access.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy is attached to.
        statement_id(str): The name of the statement. The ID is the same as the Sid IAM property. The statement name must be unique within the policy. For more information, see IAM JSON policy elements: Sid. .
        effect(str): Determines whether the statement allows or denies access to the resource.
        principal(List): An IAM principal, such as an IAM users, IAM roles, or AWS services that is allowed or denied access to a resource. For more information, see AWS JSON policy elements: Principal.
        action(List): The Amazon Lex action that this policy either allows or denies. The action must apply to the resource type of the specified ARN. For more information, see  Actions, resources, and condition keys for Amazon Lex V2.
        condition(Dict, optional): Specifies a condition when the policy is in effect. If the principal of the policy is a service principal, you must provide two condition blocks, one with a SourceAccount global condition key and one with a SourceArn global condition key. For more information, see IAM JSON policy elements: Condition . Defaults to None.
        expected_revision_id(str, optional): The identifier of the revision of the policy to edit. If this revision ID doesn't match the current revision ID, Amazon Lex throws an exception. If you don't specify a revision, Amazon Lex overwrites the contents of the policy with the new values. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.resource.policy.statement.create(
                ctx,
                resource_arn=value,
                statement_id=value,
                effect=value,
                principal=value,
                action=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.resource.policy.statement.create resource_arn=value, statement_id=value, effect=value, principal=value, action=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="create_resource_policy_statement",
        op_kwargs={
            "resourceArn": resource_arn,
            "statementId": statement_id,
            "effect": effect,
            "principal": principal,
            "action": action,
            "condition": condition,
            "expectedRevisionId": expected_revision_id,
        },
    )


async def delete(
    hub, ctx, resource_arn: str, statement_id: str, expected_revision_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a policy statement from a resource policy. If you delete the last statement from a policy, the policy is deleted. If you specify a statement ID that doesn't exist in the policy, or if the bot or bot alias doesn't have a policy attached, Amazon Lex returns an exception.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the bot or bot alias that the resource policy is attached to.
        statement_id(str): The name of the statement (SID) to delete from the policy.
        expected_revision_id(str, optional): The identifier of the revision of the policy to delete the statement from. If this revision ID doesn't match the current revision ID, Amazon Lex throws an exception. If you don't specify a revision, Amazon Lex removes the current contents of the statement. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lexv2_model.resource.policy.statement.delete(
                ctx, resource_arn=value, statement_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lexv2_model.resource.policy.statement.delete resource_arn=value, statement_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lexv2-models",
        operation="delete_resource_policy_statement",
        op_kwargs={
            "resourceArn": resource_arn,
            "statementId": statement_id,
            "expectedRevisionId": expected_revision_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(
    hub, ctx, window_id: str, window_target_id: str, safe: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a target from a maintenance window.

    Args:
        window_id(str): The ID of the maintenance window the target should be removed from.
        window_target_id(str): The ID of the target definition to remove.
        safe(bool, optional): The system checks if the target is being referenced by a task. If the target is being referenced, the system returns an error and doesn't deregister the target from the maintenance window. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.target.from_maintenance_window.deregister(
                ctx, window_id=value, window_target_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.target.from_maintenance_window.deregister window_id=value, window_target_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="deregister_target_from_maintenance_window",
        op_kwargs={
            "WindowId": window_id,
            "WindowTargetId": window_target_id,
            "Safe": safe,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(hub, ctx, instances: List) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AWS CloudFormation stack, which creates a new Amazon EC2 instance from an exported Amazon Lightsail snapshot. This operation results in a CloudFormation stack record that can be used to track the AWS CloudFormation stack created. Use the get cloud formation stack records operation to get a list of the CloudFormation stacks created.  Wait until after your new Amazon EC2 instance is created before running the create cloud formation stack operation again with the same export snapshot record.

    Args:
        instances(List): An array of parameters that will be used to create the new Amazon EC2 instance. You can only pass one instance entry at a time in this array. You will get an invalid parameter error if you pass more than one instance entry in this array.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.cloud_formation_stack.init.create(
                ctx, instances=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.cloud_formation_stack.init.create instances=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_cloud_formation_stack",
        op_kwargs={"instances": instances},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, policy_name: str, marker: str = None, page_size: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    List targets for the specified policy.

    Args:
        policy_name(str): The policy name.
        marker(str, optional): A marker used to get the next set of results. Defaults to None.
        page_size(int, optional): The maximum number of results to return at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.target.for_.policy.list(ctx, policy_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.target.for_.policy.list policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_targets_for_policy",
        op_kwargs={"policyName": policy_name, "marker": marker, "pageSize": page_size},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def archive(hub, ctx, detector_id: str, finding_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Archives GuardDuty findings that are specified by the list of finding IDs.  Only the administrator account can archive findings. Member accounts don't have permission to archive findings from their accounts.

    Args:
        detector_id(str): The ID of the detector that specifies the GuardDuty service whose findings you want to archive.
        finding_ids(List): The IDs of the findings that you want to archive.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.finding.init.archive(
                ctx, detector_id=value, finding_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.finding.init.archive detector_id=value, finding_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="archive_findings",
        op_kwargs={"DetectorId": detector_id, "FindingIds": finding_ids},
    )


async def get_all(
    hub, ctx, detector_id: str, finding_ids: List, sort_criteria: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes Amazon GuardDuty findings specified by finding IDs.

    Args:
        detector_id(str): The ID of the detector that specifies the GuardDuty service whose findings you want to retrieve.
        finding_ids(List): The IDs of the findings that you want to retrieve.
        sort_criteria(Dict, optional): Represents the criteria used for sorting findings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.finding.init.get_all(
                ctx, detector_id=value, finding_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.finding.init.get_all detector_id=value, finding_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="get_findings",
        op_kwargs={
            "DetectorId": detector_id,
            "FindingIds": finding_ids,
            "SortCriteria": sort_criteria,
        },
    )


async def list_all(
    hub,
    ctx,
    detector_id: str,
    finding_criteria: Dict = None,
    sort_criteria: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists Amazon GuardDuty findings for the specified detector ID.

    Args:
        detector_id(str): The ID of the detector that specifies the GuardDuty service whose findings you want to list.
        finding_criteria(Dict, optional): Represents the criteria used for querying findings. Valid values include:   JSON field name   accountId   region   confidence   id   resource.accessKeyDetails.accessKeyId   resource.accessKeyDetails.principalId   resource.accessKeyDetails.userName   resource.accessKeyDetails.userType   resource.instanceDetails.iamInstanceProfile.id   resource.instanceDetails.imageId   resource.instanceDetails.instanceId   resource.instanceDetails.networkInterfaces.ipv6Addresses   resource.instanceDetails.networkInterfaces.privateIpAddresses.privateIpAddress   resource.instanceDetails.networkInterfaces.publicDnsName   resource.instanceDetails.networkInterfaces.publicIp   resource.instanceDetails.networkInterfaces.securityGroups.groupId   resource.instanceDetails.networkInterfaces.securityGroups.groupName   resource.instanceDetails.networkInterfaces.subnetId   resource.instanceDetails.networkInterfaces.vpcId   resource.instanceDetails.tags.key   resource.instanceDetails.tags.value   resource.resourceType   service.action.actionType   service.action.awsApiCallAction.api   service.action.awsApiCallAction.callerType   service.action.awsApiCallAction.remoteIpDetails.city.cityName   service.action.awsApiCallAction.remoteIpDetails.country.countryName   service.action.awsApiCallAction.remoteIpDetails.ipAddressV4   service.action.awsApiCallAction.remoteIpDetails.organization.asn   service.action.awsApiCallAction.remoteIpDetails.organization.asnOrg   service.action.awsApiCallAction.serviceName   service.action.dnsRequestAction.domain   service.action.networkConnectionAction.blocked   service.action.networkConnectionAction.connectionDirection   service.action.networkConnectionAction.localPortDetails.port   service.action.networkConnectionAction.protocol   service.action.networkConnectionAction.remoteIpDetails.city.cityName   service.action.networkConnectionAction.remoteIpDetails.country.countryName   service.action.networkConnectionAction.remoteIpDetails.ipAddressV4   service.action.networkConnectionAction.remoteIpDetails.organization.asn   service.action.networkConnectionAction.remoteIpDetails.organization.asnOrg   service.action.networkConnectionAction.remotePortDetails.port   service.additionalInfo.threatListName   service.archived When this attribute is set to 'true', only archived findings are listed. When it's set to 'false', only unarchived findings are listed. When this attribute is not set, all existing findings are listed.   service.resourceRole   severity   type   updatedAt Type: Timestamp in Unix Epoch millisecond format: 1486685375000  . Defaults to None.
        sort_criteria(Dict, optional): Represents the criteria used for sorting findings. Defaults to None.
        max_results(int, optional): You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50. Defaults to None.
        next_token(str, optional): You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.finding.init.list_all(ctx, detector_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.finding.init.list_all detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_findings",
        op_kwargs={
            "DetectorId": detector_id,
            "FindingCriteria": finding_criteria,
            "SortCriteria": sort_criteria,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def unarchive(hub, ctx, detector_id: str, finding_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Unarchives GuardDuty findings specified by the findingIds.

    Args:
        detector_id(str): The ID of the detector associated with the findings to unarchive.
        finding_ids(List): The IDs of the findings to unarchive.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.finding.init.unarchive(
                ctx, detector_id=value, finding_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.finding.init.unarchive detector_id=value, finding_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="unarchive_findings",
        op_kwargs={"DetectorId": detector_id, "FindingIds": finding_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    account_id: str,
    username: str = None,
    email: str = None,
    user_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a user under the specified Amazon Chime account.

    Args:
        account_id(str): The Amazon Chime account ID.
        username(str, optional): The user name. Defaults to None.
        email(str, optional): The user's email address. Defaults to None.
        user_type(str, optional): The user type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.init.create(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.init.create account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_user",
        op_kwargs={
            "AccountId": account_id,
            "Username": username,
            "Email": email,
            "UserType": user_type,
        },
    )


async def get(hub, ctx, account_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details for the specified user ID, such as primary email address, license type,and personal meeting PIN.  To retrieve user details with an email address instead of a user ID, use the ListUsers action, and then filter by email address.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id(str): The user ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.init.get(ctx, account_id=value, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.init.get account_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_user",
        op_kwargs={"AccountId": account_id, "UserId": user_id},
    )


async def invite(
    hub, ctx, account_id: str, user_email_list: List, user_type: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Sends email to a maximum of 50 users, inviting them to the specified Amazon Chime Team account. Only Team account types are currently supported for this action.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_email_list(List): The user email addresses to which to send the email invitation.
        user_type(str, optional): The user type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.init.invite(
                ctx, account_id=value, user_email_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.init.invite account_id=value, user_email_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="invite_users",
        op_kwargs={
            "AccountId": account_id,
            "UserEmailList": user_email_list,
            "UserType": user_type,
        },
    )


async def list_all(
    hub,
    ctx,
    account_id: str,
    user_email: str = None,
    user_type: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the users that belong to the specified Amazon Chime account. You can specify an email address to list only the user that the email address belongs to.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_email(str, optional): Optional. The user email address used to filter results. Maximum 1. Defaults to None.
        user_type(str, optional): The user type. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to 100. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.init.list_all(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.init.list_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_users",
        op_kwargs={
            "AccountId": account_id,
            "UserEmail": user_email,
            "UserType": user_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def logout(hub, ctx, account_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Logs out the specified user from all of the devices they are currently logged into.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id(str): The user ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.init.logout(ctx, account_id=value, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.init.logout account_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="logout_user",
        op_kwargs={"AccountId": account_id, "UserId": user_id},
    )


async def update(
    hub,
    ctx,
    account_id: str,
    user_id: str,
    license_type: str = None,
    user_type: str = None,
    alexa_for_business_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates user details for a specified user ID. Currently, only LicenseType updates are supported for this action.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id(str): The user ID.
        license_type(str, optional): The user license type to update. This must be a supported license type for the Amazon Chime account that the user belongs to. Defaults to None.
        user_type(str, optional): The user type. Defaults to None.
        alexa_for_business_metadata(Dict, optional): The Alexa for Business metadata. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.user.init.update(ctx, account_id=value, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.user.init.update account_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_user",
        op_kwargs={
            "AccountId": account_id,
            "UserId": user_id,
            "LicenseType": license_type,
            "UserType": user_type,
            "AlexaForBusinessMetadata": alexa_for_business_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, security_configuration: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a security configuration, which is stored in the service and can be specified when a cluster is created.

    Args:
        name(str): The name of the security configuration.
        security_configuration(str): The security configuration details in JSON format. For JSON parameters and examples, see Use Security Configurations to Set Up Cluster Security in the Amazon EMR Management Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.security_configuration.create(
                ctx, name=value, security_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.security_configuration.create name=value, security_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="create_security_configuration",
        op_kwargs={"Name": name, "SecurityConfiguration": security_configuration},
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a security configuration.

    Args:
        name(str): The name of the security configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.security_configuration.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.security_configuration.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="delete_security_configuration",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides the details of a security configuration by returning the configuration JSON.

    Args:
        name(str): The name of the security configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.security_configuration.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.security_configuration.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="describe_security_configuration",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, marker: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the security configurations visible to this account, providing their creation dates and times, and their names. This call returns a maximum of 50 clusters per call, but returns a marker to track the paging of the cluster list across multiple ListSecurityConfigurations calls.

    Args:
        marker(str, optional): The pagination token that indicates the set of results to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.security_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.security_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_security_configurations",
        op_kwargs={"Marker": marker},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    interconnect_name: str,
    bandwidth: str,
    location: str,
    lag_id: str = None,
    tags: List = None,
    provider_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an interconnect between an Direct Connect Partner's network and a specific Direct Connect location. An interconnect is a connection that is capable of hosting other connections. The Direct Connect Partner can use an interconnect to provide Direct Connect hosted connections to customers through their own network services. Like a standard connection, an interconnect links the partner's network to an Direct Connect location over a standard Ethernet fiber-optic cable. One end is connected to the partner's router, the other to an Direct Connect router. You can automatically add the new interconnect to a link aggregation group (LAG) by specifying a LAG ID in the request. This ensures that the new interconnect is allocated on the same Direct Connect endpoint that hosts the specified LAG. If there are no available ports on the endpoint, the request fails and no interconnect is created. For each end customer, the Direct Connect Partner provisions a connection on their interconnect by calling AllocateHostedConnection. The end customer can then connect to Amazon Web Services resources by creating a virtual interface on their connection, using the VLAN assigned to them by the Direct Connect Partner.  Intended for use by Direct Connect Partners only.

    Args:
        interconnect_name(str): The name of the interconnect.
        bandwidth(str): The port bandwidth, in Gbps. The possible values are 1 and 10.
        location(str): The location of the interconnect.
        lag_id(str, optional): The ID of the LAG. Defaults to None.
        tags(List, optional): The tags to associate with the interconnect. Defaults to None.
        provider_name(str, optional): The name of the service provider associated with the interconnect. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.interconnect.init.create(
                ctx, interconnect_name=value, bandwidth=value, location=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.interconnect.init.create interconnect_name=value, bandwidth=value, location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="create_interconnect",
        op_kwargs={
            "interconnectName": interconnect_name,
            "bandwidth": bandwidth,
            "location": location,
            "lagId": lag_id,
            "tags": tags,
            "providerName": provider_name,
        },
    )


async def delete(hub, ctx, interconnect_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified interconnect.  Intended for use by Direct Connect Partners only.

    Args:
        interconnect_id(str): The ID of the interconnect.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.interconnect.init.delete(
                ctx, interconnect_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.interconnect.init.delete interconnect_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="delete_interconnect",
        op_kwargs={"interconnectId": interconnect_id},
    )


async def describe_all(hub, ctx, interconnect_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the interconnects owned by the account or only the specified interconnect.

    Args:
        interconnect_id(str, optional): The ID of the interconnect. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.interconnect.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.interconnect.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_interconnects",
        op_kwargs={"interconnectId": interconnect_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, stack_name: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns all stack related events for a specified stack in reverse chronological order. For more information about a stack's event history, go to Stacks in the CloudFormation User Guide.  You can list events for stacks that have failed to create or have been deleted by specifying the unique stack identifier (stack ID).

    Args:
        stack_name(str, optional): The name or the unique stack ID that is associated with the stack, which are not always interchangeable:   Running stacks: You can specify either the stack's name or its unique stack ID.   Deleted stacks: You must specify the unique stack ID.   Default: There is no default value. Defaults to None.
        next_token(str, optional): A string that identifies the next page of events that you want to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.event.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.event.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="describe_stack_events",
        op_kwargs={"StackName": stack_name, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, assessment_run_arn: str, report_file_format: str, report_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Produces an assessment report that includes detailed and comprehensive results of a specified assessment run.

    Args:
        assessment_run_arn(str): The ARN that specifies the assessment run for which you want to generate a report.
        report_file_format(str): Specifies the file format (html or pdf) of the assessment report that you want to generate.
        report_type(str): Specifies the type of the assessment report that you want to generate. There are two types of assessment reports: a finding report and a full report. For more information, see Assessment Reports. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.assessment.report.get(
                ctx, assessment_run_arn=value, report_file_format=value, report_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.assessment.report.get assessment_run_arn=value, report_file_format=value, report_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="get_assessment_report",
        op_kwargs={
            "assessmentRunArn": assessment_run_arn,
            "reportFileFormat": report_file_format,
            "reportType": report_type,
        },
    )
